@@ -14,21 +14,16 @@
 
 import os
 
+import magnum.conf
 from magnum.drivers.common import k8s_template_def
-from oslo_config import cfg
+from magnum.drivers.common import template_def
 
-CONF = cfg.CONF
+CONF = magnum.conf.CONF
 
 
 class JeOSK8sTemplateDefinition(k8s_template_def.K8sTemplateDefinition):
     """Kubernetes template for openSUSE/SLES JeOS VM."""
 
-    provides = [
-        {'server_type': 'vm',
-         'os': 'opensuse',
-         'coe': 'kubernetes'},
-    ]
-
     def __init__(self):
         super(JeOSK8sTemplateDefinition, self).__init__()
         self.add_parameter('docker_volume_size',
@@ -49,6 +44,27 @@ class JeOSK8sTemplateDefinition(k8s_template_def.K8sTemplateDefinition):
                                       extra_params=extra_params,
                                       **kwargs)
 
+    def get_env_files(self, cluster):
+        env_files = []
+        if cluster.master_lb_enabled:
+            env_files.append(
+                template_def.COMMON_ENV_PATH + 'with_master_lb.yaml')
+        else:
+            env_files.append(
+                template_def.COMMON_ENV_PATH + 'no_master_lb.yaml')
+        if cluster.floating_ip_enabled:
+            env_files.append(
+                template_def.COMMON_ENV_PATH + 'enable_floating_ip.yaml')
+        else:
+            env_files.append(
+                template_def.COMMON_ENV_PATH + 'disable_floating_ip.yaml')
+
+        return env_files
+
+    @property
+    def driver_module_path(self):
+        return __name__[:__name__.rindex('.')]
+
     @property
     def template_path(self):
         return os.path.join(os.path.dirname(os.path.realpath(__file__)),
