@@ -14,7 +14,6 @@
 
 from glanceclient import exc as glance_exception
 from novaclient import exceptions as nova_exception
-from oslo_serialization import jsonutils
 
 from magnum.api import utils as api_utils
 from magnum.common import clients
@@ -28,7 +27,6 @@ SUPPORTED_ISOLATION = ['filesystem/posix', 'filesystem/linux',
                        'cgroups/mem', 'docker/runtime',
                        'namespaces/pid']
 SUPPORTED_IMAGE_PROVIDERS = ['docker', 'appc']
-SUPPORTED_SWARM_STRATEGY = ['spread', 'binpack', 'random']
 
 
 def validate_image(cli, image):
@@ -100,9 +98,45 @@ def validate_external_network(cli, external_network):
 def validate_fixed_network(cli, fixed_network):
     """Validate fixed network"""
 
-    # TODO(houming):this method implement will be added after this
-    # first pathch for Cluster's OpenStack resources validation is merged.
-    pass
+    count = 0
+    network_id = None
+    networks = cli.neutron().list_networks()
+    for net in networks.get('networks'):
+        if fixed_network in [net.get('name'), net.get('id')]:
+            count += 1
+            network_id = net.get('id')
+
+    if count == 0:
+        # Unable to find the configured fixed_network.
+        raise exception.FixedNetworkNotFound(network=fixed_network)
+    elif count > 1:
+        msg = _("Multiple networks exist with same name '%s'. "
+                "Please use the network ID instead.")
+        raise exception.Conflict(msg % fixed_network)
+
+    return network_id
+
+
+def validate_fixed_subnet(cli, fixed_subnet):
+    """Validate fixed subnet"""
+
+    count = 0
+    subnet_id = None
+    subnets = cli.neutron().list_subnets()
+    for subnet in subnets.get('subnets'):
+        if fixed_subnet in [subnet.get('name'), subnet.get('id')]:
+            count += 1
+            subnet_id = subnet.get('id')
+
+    if count == 0:
+        # Unable to find the configured fixed_subnet.
+        raise exception.FixedSubnetNotFound(subnet=fixed_subnet)
+    elif count > 1:
+        msg = _("Multiple subnets exist with same name '%s'. "
+                "Please use the subnet ID instead.")
+        raise exception.Conflict(msg % fixed_subnet)
+    else:
+        return subnet_id
 
 
 def validate_labels(labels):
@@ -113,79 +147,6 @@ def validate_labels(labels):
             validate_method(labels)
 
 
-def validate_labels_isolation(labels):
-    """Validate mesos_slave_isolation"""
-    mesos_slave_isolation = labels.get('mesos_slave_isolation')
-    mesos_slave_isolation_list = mesos_slave_isolation.split(',')
-    unsupported_isolations = set(mesos_slave_isolation_list) - set(
-        SUPPORTED_ISOLATION)
-    if (len(unsupported_isolations) > 0):
-        raise exception.InvalidParameterValue(_(
-            'property "labels/mesos_slave_isolation" with value '
-            '"%(isolation_val)s" is not supported, supported values are: '
-            '%(supported_isolation)s') % {
-                'isolation_val': ', '.join(list(unsupported_isolations)),
-                'supported_isolation': ', '.join(
-                    SUPPORTED_ISOLATION + ['unspecified'])})
-
-
-def validate_labels_image_providers(labels):
-    """Validate mesos_slave_image_providers"""
-    mesos_slave_image_providers = labels.get('mesos_slave_image_providers')
-    mesos_slave_image_providers_list = mesos_slave_image_providers.split(',')
-    isolation_with_valid_data = False
-    for image_providers_val in mesos_slave_image_providers_list:
-        image_providers_val = image_providers_val.lower()
-        if image_providers_val not in SUPPORTED_IMAGE_PROVIDERS:
-            raise exception.InvalidParameterValue(_(
-                'property "labels/mesos_slave_image_providers" with value '
-                '"%(image_providers)s" is not supported, supported values '
-                'are: %(supported_image_providers)s') % {
-                'image_providers': image_providers_val,
-                'supported_image_providers': ', '.join(
-                    SUPPORTED_IMAGE_PROVIDERS + ['unspecified'])})
-
-        if image_providers_val == 'docker':
-            mesos_slave_isolation = labels.get('mesos_slave_isolation')
-            if mesos_slave_isolation is not None:
-                mesos_slave_isolation_list = mesos_slave_isolation.split(',')
-                for isolations_val in mesos_slave_isolation_list:
-                    if isolations_val == 'docker/runtime':
-                        isolation_with_valid_data = True
-            if mesos_slave_isolation is None or not isolation_with_valid_data:
-                raise exception.RequiredParameterNotProvided(_(
-                    "Docker runtime isolator has to be specified if 'docker' "
-                    "is included in 'mesos_slave_image_providers' Please add "
-                    "'docker/runtime' to 'mesos_slave_isolation' labels "
-                    "flags"))
-
-
-def validate_labels_executor_env_variables(labels):
-    """Validate executor_environment_variables"""
-    mesos_slave_executor_env_val = labels.get(
-        'mesos_slave_executor_env_variables')
-    try:
-        jsonutils.loads(mesos_slave_executor_env_val)
-    except ValueError:
-        err = (_("Json format error"))
-        raise exception.InvalidParameterValue(err)
-
-
-def validate_labels_strategy(labels):
-    """Validate swarm_strategy"""
-    swarm_strategy = list(labels.get('swarm_strategy', "").split())
-    unsupported_strategy = set(swarm_strategy) - set(
-        SUPPORTED_SWARM_STRATEGY)
-    if (len(unsupported_strategy) > 0):
-        raise exception.InvalidParameterValue(_(
-            'property "labels/swarm_strategy" with value '
-            '"%(strategy)s" is not supported, supported values are: '
-            '%(supported_strategies)s') % {
-                'strategy': ' '.join(list(unsupported_strategy)),
-                'supported_strategies': ', '.join(
-                    SUPPORTED_SWARM_STRATEGY + ['unspecified'])})
-
-
 def validate_os_resources(context, cluster_template, cluster=None):
     """Validate ClusterTemplate's OpenStack Resources"""
 
@@ -193,27 +154,49 @@ def validate_os_resources(context, cluster_template, cluster=None):
 
     for attr, validate_method in validators.items():
         if cluster and attr in cluster and cluster[attr]:
-            if attr != 'labels':
-                validate_method(cli, cluster[attr])
-            else:
+            if attr == 'labels':
                 validate_method(cluster[attr])
-        elif attr in cluster_template and cluster_template[attr] is not None:
-            if attr != 'labels':
-                validate_method(cli, cluster_template[attr])
             else:
+                validate_method(cli, cluster[attr])
+        elif attr in cluster_template and cluster_template[attr] is not None:
+            if attr == 'labels':
                 validate_method(cluster_template[attr])
+            else:
+                validate_method(cli, cluster_template[attr])
 
     if cluster:
         validate_keypair(cli, cluster['keypair'])
 
 
-def validate_master_count(cluster, cluster_template):
-    if cluster['master_count'] > 1 and \
-            not cluster_template['master_lb_enabled']:
+def validate_master_count(context, cluster):
+    if (
+        cluster['master_count'] > 1 and
+        not cluster['master_lb_enabled']
+    ):
         raise exception.InvalidParameterValue(_(
             "master_count must be 1 when master_lb_enabled is False"))
 
 
+def validate_flavor_root_volume_size(cli, flavor, boot_volume_size):
+    """Validate flavor root volume size."""
+
+    if boot_volume_size > 0:
+        return
+
+    flavor_obj = None
+    flavor_list = cli.nova().flavors.list()
+    for f in flavor_list:
+        if f.name == flavor or f.id == flavor:
+            flavor_obj = f
+            break
+
+    if flavor_obj is None:
+        raise exception.FlavorNotFound(flavor=flavor)
+
+    if flavor_obj.disk == 0 and boot_volume_size == 0:
+        raise exception.FlavorZeroRootVolumeNotSupported()
+
+
 def validate_federation_hostcluster(cluster_uuid):
     """Validate Federation `hostcluster_id` parameter.
 
@@ -247,11 +230,7 @@ validators = {'image_id': validate_image,
               'master_flavor_id': validate_flavor,
               'external_network_id': validate_external_network,
               'fixed_network': validate_fixed_network,
+              'fixed_subnet': validate_fixed_subnet,
               'labels': validate_labels}
 
-labels_validators = {'mesos_slave_isolation': validate_labels_isolation,
-                     'mesos_slave_image_providers':
-                     validate_labels_image_providers,
-                     'mesos_slave_executor_env_variables':
-                     validate_labels_executor_env_variables,
-                     'swarm_strategy': validate_labels_strategy}
+labels_validators = {}
