@@ -71,10 +71,6 @@ class Certificate(base.APIBase):
         elif value == wtypes.Unset:
             self._cluster_uuid = wtypes.Unset
 
-    bay_uuid = wsme.wsproperty(wtypes.text, _get_cluster_uuid,
-                               _set_cluster_uuid)
-    """The bay UUID or id"""
-
     cluster_uuid = wsme.wsproperty(wtypes.text, _get_cluster_uuid,
                                    _set_cluster_uuid)
     """The cluster UUID or id"""
@@ -88,6 +84,9 @@ class Certificate(base.APIBase):
     pem = wtypes.StringType()
     """"The Signed Certificate"""
 
+    ca_cert_type = wtypes.StringType()
+    """"The CA Certificate type the CSR will be signed by"""
+
     def __init__(self, **kwargs):
         super(Certificate, self).__init__()
 
@@ -99,10 +98,6 @@ class Certificate(base.APIBase):
             self.fields.append(field)
             setattr(self, field, kwargs.get(field, wtypes.Unset))
 
-        # set the attribute for bay_uuid for backwards compatibility
-        self.fields.append('bay_uuid')
-        setattr(self, 'bay_uuid', kwargs.get('bay_uuid',  self._cluster_uuid))
-
     def get_cluster(self):
         if not self._cluster:
             self._cluster = api_utils.get_resource('Cluster',
@@ -112,8 +107,8 @@ class Certificate(base.APIBase):
     @staticmethod
     def _convert_with_links(certificate, url, expand=True):
         if not expand:
-            certificate.unset_fields_except(['bay_uuid', 'cluster_uuid',
-                                             'csr', 'pem'])
+            certificate.unset_fields_except(['cluster_uuid',
+                                             'csr', 'pem', 'ca_cert_type'])
 
         certificate.links = [link.Link.make_link('self', url,
                                                  'certificates',
@@ -132,10 +127,10 @@ class Certificate(base.APIBase):
 
     @classmethod
     def sample(cls, expand=True):
-        sample = cls(bay_uuid='7ae81bb3-dec3-4289-8d6c-da80bd8001ae',
-                     cluster_uuid='7ae81bb3-dec3-4289-8d6c-da80bd8001ae',
+        sample = cls(cluster_uuid='7ae81bb3-dec3-4289-8d6c-da80bd8001ae',
                      created_at=timeutils.utcnow(),
-                     csr='AAA....AAA')
+                     csr='AAA....AAA',
+                     ca_cert_type='kubernetes')
         return cls._convert_with_links(sample, 'http://localhost:9511', expand)
 
 
@@ -149,8 +144,8 @@ class CertificateController(base.Controller):
         'detail': ['GET'],
     }
 
-    @expose.expose(Certificate, types.uuid_or_name)
-    def get_one(self, cluster_ident):
+    @expose.expose(Certificate, types.uuid_or_name, wtypes.text)
+    def get_one(self, cluster_ident, ca_cert_type=None):
         """Retrieve CA information about the given cluster.
 
         :param cluster_ident: UUID of a cluster or
@@ -160,7 +155,8 @@ class CertificateController(base.Controller):
         cluster = api_utils.get_resource('Cluster', cluster_ident)
         policy.enforce(context, 'certificate:get', cluster.as_dict(),
                        action='certificate:get')
-        certificate = pecan.request.rpcapi.get_ca_certificate(cluster)
+        certificate = pecan.request.rpcapi.get_ca_certificate(cluster,
+                                                              ca_cert_type)
         return Certificate.convert_with_links(certificate)
 
     @expose.expose(Certificate, body=Certificate, status_code=201)
