@@ -14,22 +14,26 @@
 #    under the License.
 
 import pecan
-import six
 import uuid
 import wsme
 from wsme import types as wtypes
 
+from magnum.api import attr_validator
 from magnum.api.controllers import base
 from magnum.api.controllers import link
 from magnum.api.controllers.v1 import collection
 from magnum.api.controllers.v1 import types
 from magnum.api import expose
 from magnum.api import utils as api_utils
+from magnum.common import clients
 from magnum.common import exception
 from magnum.common import policy
+import magnum.conf
 from magnum import objects
 from magnum.objects import fields
 
+CONF = magnum.conf.CONF
+
 
 def _validate_node_count(ng):
     if ng.max_node_count:
@@ -80,10 +84,10 @@ class NodeGroup(base.APIBase):
     docker_volume_size = wtypes.IntegerType(minimum=1)
     """The size in GB of the docker volume"""
 
-    labels = wtypes.DictType(wtypes.text, types.MultiType(wtypes.text,
-                                                          six.integer_types,
-                                                          bool,
-                                                          float))
+    labels = wtypes.DictType(
+        wtypes.text,
+        types.MultiType(wtypes.text, int, bool, float)
+    )
     """One or more key/value pairs"""
 
     links = wsme.wsattr([link.Link], readonly=True)
@@ -98,18 +102,18 @@ class NodeGroup(base.APIBase):
     node_addresses = wsme.wsattr([wtypes.text], readonly=True)
     """IP addresses of nodegroup nodes"""
 
-    node_count = wsme.wsattr(wtypes.IntegerType(minimum=1), default=1)
+    node_count = wsme.wsattr(wtypes.IntegerType(minimum=0), default=1)
     """The node count for this nodegroup. Default to 1 if not set"""
 
     role = wsme.wsattr(wtypes.StringType(min_length=1, max_length=255),
                        default='worker')
     """The role of the nodes included in this nodegroup"""
 
-    min_node_count = wsme.wsattr(wtypes.IntegerType(minimum=1), default=1)
-    """The minimum allowed nodes for this nodegroup. Default to 1 if not set"""
+    min_node_count = wsme.wsattr(wtypes.IntegerType(minimum=0), default=0)
+    """The minimum allowed nodes for this nodegroup. Default to 0 if not set"""
 
-    max_node_count = wsme.wsattr(wtypes.IntegerType(minimum=1), default=None)
-    """The maximum allowed nodes for this nodegroup. Default to 1 if not set"""
+    max_node_count = wsme.wsattr(wtypes.IntegerType(minimum=0), default=None)
+    """The maximum allowed nodes for this nodegroup."""
 
     is_default = types.BooleanType()
     """Specifies is a nodegroup was created by default or not"""
@@ -130,18 +134,21 @@ class NodeGroup(base.APIBase):
     """Indicates whether the labels will be merged with the cluster labels."""
 
     labels_overridden = wtypes.DictType(
-            wtypes.text, types.MultiType(
-                wtypes.text, six.integer_types, bool, float))
+        wtypes.text,
+        types.MultiType(wtypes.text, int, bool, float)
+    )
     """Contains labels that have a value different than the parent labels."""
 
     labels_added = wtypes.DictType(
-            wtypes.text, types.MultiType(
-                wtypes.text, six.integer_types, bool, float))
+        wtypes.text,
+        types.MultiType(wtypes.text, int, bool, float)
+    )
     """Contains labels that do not exist in the parent."""
 
     labels_skipped = wtypes.DictType(
-            wtypes.text, types.MultiType(
-                wtypes.text, six.integer_types, bool, float))
+        wtypes.text,
+        types.MultiType(wtypes.text, int, bool, float)
+    )
     """Contains labels that exist in the parent but were not inherited."""
 
     def __init__(self, **kwargs):
@@ -348,6 +355,13 @@ class NodeGroupController(base.Controller):
                 labels.update(nodegroup.labels)
                 nodegroup.labels = labels
 
+        # check root volume size
+        boot_volume_size = cluster.labels.get(
+            'boot_volume_size', CONF.cinder.default_boot_volume_size)
+        cli = clients.OpenStackClients(context)
+        attr_validator.validate_flavor_root_volume_size(
+            cli, nodegroup.flavor_id, boot_volume_size)
+
         nodegroup_dict = nodegroup.as_dict()
         nodegroup_dict['cluster_id'] = cluster.uuid
         nodegroup_dict['project_id'] = context.project_id
@@ -412,6 +426,15 @@ class NodeGroupController(base.Controller):
                 patch_val = None
             if nodegroup[field] != patch_val:
                 nodegroup[field] = patch_val
+
+        # check root volume size
+        cluster = api_utils.get_resource('Cluster', cluster_uuid)
+        boot_volume_size = cluster.labels.get(
+            'boot_volume_size', CONF.cinder.default_boot_volume_size)
+        cli = clients.OpenStackClients(context)
+        attr_validator.validate_flavor_root_volume_size(
+            cli, nodegroup.flavor_id, boot_volume_size)
+
         _validate_node_count(nodegroup)
 
         return nodegroup
