@@ -25,37 +25,15 @@ import re
 import shutil
 import tempfile
 
+import netaddr
 from oslo_concurrency import processutils
-from oslo_config import cfg
 from oslo_log import log as logging
-import six
+from oslo_utils import netutils
 
 from magnum.common import exception
-from magnum.i18n import _LE
-from magnum.i18n import _LW
-
-
-# Default symbols to use for passwords. Avoids visually confusing characters.
-# ~6 bits per symbol
-DEFAULT_PASSWORD_SYMBOLS = ['23456789',  # Removed: 0,1
-                            'ABCDEFGHJKLMNPQRSTUVWXYZ',   # Removed: I, O
-                            'abcdefghijkmnopqrstuvwxyz']  # Removed: l
-
-UTILS_OPTS = [
-    cfg.StrOpt('rootwrap_config',
-               default="/etc/magnum/rootwrap.conf",
-               help='Path to the rootwrap configuration file to use for '
-                    'running commands as root.'),
-    cfg.StrOpt('tempdir',
-               help='Explicitly specify the temporary working directory.'),
-    cfg.ListOpt('password_symbols',
-                default=DEFAULT_PASSWORD_SYMBOLS,
-                help='Symbols to use for passwords')
-]
-
-CONF = cfg.CONF
-CONF.register_opts(UTILS_OPTS)
+import magnum.conf
 
+CONF = magnum.conf.CONF
 LOG = logging.getLogger(__name__)
 
 MEMORY_UNITS = {
@@ -121,22 +99,6 @@ def trycmd(*args, **kwargs):
     return processutils.trycmd(*args, **kwargs)
 
 
-def is_valid_mac(address):
-    """Verify the format of a MAC address.
-
-    Check if a MAC address is valid and contains six octets. Accepts
-    colon-separated format only.
-
-    :param address: MAC address to be validated.
-    :returns: True if valid. False if not.
-
-    """
-    m = "[0-9a-f]{2}(:[0-9a-f]{2}){5}$"
-    if isinstance(address, six.string_types) and re.match(m, address.lower()):
-        return True
-    return False
-
-
 def validate_and_normalize_mac(address):
     """Validate a MAC address and return normalized form.
 
@@ -148,11 +110,29 @@ def validate_and_normalize_mac(address):
     :raises: InvalidMAC If the MAC address is not valid.
 
     """
-    if not is_valid_mac(address):
+    if not netutils.is_valid_mac(address):
         raise exception.InvalidMAC(mac=address)
     return address.lower()
 
 
+def validate_dns(dns_list):
+    """Validate a string is a single dns address or comma separated dns list
+
+    :param dns_list: dns_list to be validated
+    :returns: original dns_list.
+    :raise: InvalidDNS if dns format is invalid
+
+    """
+    dns_nameservers = dns_list.split(',')
+    try:
+        for dns in dns_nameservers:
+            netaddr.IPAddress(dns.strip(), version=4, flags=netaddr.INET_PTON)
+    except netaddr.AddrFormatError:
+        raise exception.InvalidDNS(dns=dns_list)
+    else:
+        return dns_list
+
+
 @contextlib.contextmanager
 def tempdir(**kwargs):
     tempfile.tempdir = CONF.tempdir
@@ -163,7 +143,7 @@ def tempdir(**kwargs):
         try:
             shutil.rmtree(tmpdir)
         except OSError as e:
-            LOG.error(_LE('Could not remove tmpdir: %s'), e)
+            LOG.error('Could not remove tmpdir: %s', e)
 
 
 def rmtree_without_raise(path):
@@ -171,7 +151,7 @@ def rmtree_without_raise(path):
         if os.path.isdir(path):
             shutil.rmtree(path)
     except OSError as e:
-        LOG.warning(_LW("Failed to remove dir %(path)s, error: %(e)s"),
+        LOG.warning("Failed to remove dir %(path)s, error: %(e)s",
                     {'path': path, 'e': e})
 
 
@@ -183,11 +163,10 @@ def safe_rstrip(value, chars=None):
     :return: Stripped value.
 
     """
-    if not isinstance(value, six.string_types):
-        LOG.warning(_LW(
-            "Failed to remove trailing character. Returning original object. "
-            "Supplied object is not a string: %s,"
-        ), value)
+    if not isinstance(value, str):
+        LOG.warning("Failed to remove trailing character. "
+                    "Returning original object. "
+                    "Supplied object is not a string: %s,", value)
         return value
 
     return value.rstrip(chars) or value
@@ -253,35 +232,6 @@ def get_k8s_quantity(quantity):
         raise exception.UnsupportedK8sQuantityFormat()
 
 
-def get_docker_quantity(quantity):
-    """This function is used to get swarm Memory quantity.
-
-     Memory format must be in the format of:
-
-        <unsignedNumber><suffix>
-        suffix = b | k | m | g
-
-    eg:  100m = 104857600
-    :raises: exception.UnsupportedDockerQuantityFormat if the quantity string
-             is a unsupported value
-    """
-    matched_unsigned_number = re.search(r"(^\d+)", quantity)
-
-    if matched_unsigned_number is None:
-        raise exception.UnsupportedDockerQuantityFormat()
-    else:
-        unsigned_number = matched_unsigned_number.group(0)
-
-    suffix = quantity.replace(unsigned_number, '', 1)
-    if suffix == '':
-        return int(quantity)
-
-    if re.search(r"^(b|k|m|g)$", suffix):
-        return int(unsigned_number) * DOCKER_MEMORY_UNITS[suffix]
-
-    raise exception.UnsupportedDockerQuantityFormat()
-
-
 def generate_password(length, symbolgroups=None):
     """Generate a random password from the supplied symbol groups.
 
@@ -317,3 +267,13 @@ def generate_password(length, symbolgroups=None):
     r.shuffle(password)
 
     return ''.join(password)
+
+
+def get_openstack_ca():
+    openstack_ca_file = CONF.drivers.openstack_ca_file
+
+    if openstack_ca_file:
+        with open(openstack_ca_file) as fd:
+            return fd.read()
+    else:
+        return ''
