@@ -25,9 +25,8 @@ CONF = magnum.conf.CONF
 
 @profiler.trace_cls("rpc")
 class API(rpc_service.API):
-    def __init__(self, transport=None, context=None, topic=None):
-        super(API, self).__init__(transport, context,
-                                  topic=CONF.conductor.topic)
+    def __init__(self, context=None, topic=CONF.conductor.topic):
+        super(API, self).__init__(context=context, topic=topic)
 
     # Cluster Operations
 
@@ -127,8 +126,9 @@ class API(rpc_service.API):
         return self._call('sign_certificate', cluster=cluster,
                           certificate=certificate)
 
-    def get_ca_certificate(self, cluster):
-        return self._call('get_ca_certificate', cluster=cluster)
+    def get_ca_certificate(self, cluster, ca_cert_type=None):
+        return self._call('get_ca_certificate', cluster=cluster,
+                          ca_cert_type=ca_cert_type)
 
     def rotate_ca_certificate(self, cluster):
         return self._call('rotate_ca_certificate', cluster=cluster)
@@ -175,6 +175,14 @@ class API(rpc_service.API):
     def nodegroup_update_async(self, cluster, nodegroup):
         self._cast('nodegroup_update', cluster=cluster, nodegroup=nodegroup)
 
+    # Credential Operations
+
+    def credential_rotate(self, cluster):
+        return self._call('credential_rotate', cluster=cluster)
+
+    def credential_rotate_async(self, cluster):
+        return self._cast('credential_rotate', cluster=cluster)
+
 
 @profiler.trace_cls("rpc")
 class ListenerAPI(rpc_service.API):
