@@ -22,31 +22,24 @@ Create Date: 2015-04-17 14:20:17.620995
 revision = '592131657ca1'
 down_revision = '4956f03cabad'
 
-from alembic import op
-from oslo_config import cfg
-import sqlalchemy as sa
+from alembic import op  # noqa: E402
 
-from magnum.i18n import _
+from sqlalchemy.types import String  # noqa: E402
 
+import magnum.conf  # noqa: E402
+import sqlalchemy as sa  # noqa: E402
 
-cluster_heat_opts = [
-    cfg.StrOpt('cluster_coe',
-               default='kubernetes',
-               help=_('Container Orchestration Environments are '
-                      'kubernetes or swarm.'),
-               deprecated_group='bay_heat')
-]
-cfg.CONF.register_opts(cluster_heat_opts, group='cluster_heat')
+CONF = magnum.conf.CONF
 
 
 def upgrade():
-    op.add_column('baymodel', sa.Column('coe', sa.String(length=255),
+    op.add_column('baymodel', sa.Column('coe', String(255),
                                         nullable=True))
 
     baymodel = sa.sql.table('baymodel',
-                            sa.sql.column('coe', sa.String(length=255)))
+                            sa.sql.column('coe', String(255)))
 
     op.execute(
         baymodel.update().values({
-            'coe': op.inline_literal(cfg.CONF.cluster_heat.cluster_coe)})
+            'coe': op.inline_literal("kubernetes")})
     )
