@@ -21,10 +21,13 @@ from oslo_service import periodic_task
 
 from pycadf import cadftaxonomy as taxonomy
 
+from magnum.common import clients
 from magnum.common import context
 from magnum.common import exception
 from magnum.common import profiler
 from magnum.common import rpc
+from magnum.conductor.handlers.common import cert_manager
+from magnum.conductor.handlers.common import trust_manager
 from magnum.conductor import monitors
 from magnum.conductor import utils as conductor_utils
 import magnum.conf
@@ -64,7 +67,7 @@ class ClusterUpdateJob(object):
         self.cluster = cluster
 
     def update_status(self):
-        LOG.debug("Updating status for cluster %s", self.cluster.id)
+        LOG.debug("Updating status for cluster %s", self.cluster.uuid)
         # get the driver for the cluster
         cdriver = driver.Driver.get_driver_for_cluster(self.ctx, self.cluster)
         # ask the driver to sync status
@@ -82,7 +85,7 @@ class ClusterUpdateJob(object):
                 raise
 
         LOG.debug("Status for cluster %s updated to %s (%s)",
-                  self.cluster.id, self.cluster.status,
+                  self.cluster.uuid, self.cluster.status,
                   self.cluster.status_reason)
         # status update notifications
         if self.cluster.status.endswith("_COMPLETE"):
@@ -95,6 +98,14 @@ class ClusterUpdateJob(object):
                 taxonomy.OUTCOME_FAILURE, self.cluster)
         # if we're done with it, delete it
         if self.cluster.status == objects.fields.ClusterStatus.DELETE_COMPLETE:
+            # Clean up trusts and certificates, if they still exist.
+            os_client = clients.OpenStackClients(self.ctx)
+            LOG.debug("Calling delete_trustee_and_trusts from periodic "
+                      "DELETE_COMPLETE")
+            trust_manager.delete_trustee_and_trust(os_client, self.ctx,
+                                                   self.cluster)
+            cert_manager.delete_certificates_from_cluster(self.cluster,
+                                                          context=self.ctx)
             # delete all the nodegroups that belong to this cluster
             for ng in objects.NodeGroup.list(self.ctx, self.cluster.uuid):
                 ng.destroy()
@@ -133,10 +144,10 @@ class ClusterHealthUpdateJob(object):
             self.cluster.save()
 
     def update_health_status(self):
-        LOG.debug("Updating health status for cluster %s", self.cluster.id)
+        LOG.debug("Updating health status for cluster %s", self.cluster.uuid)
         self._update_health_status()
         LOG.debug("Status for cluster %s updated to %s (%s)",
-                  self.cluster.id, self.cluster.health_status,
+                  self.cluster.uuid, self.cluster.health_status,
                   self.cluster.health_status_reason)
         # TODO(flwang): Health status update notifications?
         # end the "loop"
