@@ -21,4 +21,10 @@ class TestFedoraKubernetesIronicAPIs(base.BaseK8sTest):
         "volume_driver": None,
         "fixed_subnet": 'private-subnet',
         "server_type": 'bm',
+        "docker_storage_driver": 'overlay',
+        "labels": {
+            "system_pods_initial_delay": 3600,
+            "system_pods_timeout": 600,
+            "kube_dashboard_enabled": False
+        }
     }
