@@ -19,6 +19,7 @@ from unittest import mock
 from oslo_utils import timeutils
 from oslo_utils import uuidutils
 
+from magnum.api import attr_validator
 from magnum.api.controllers.v1 import nodegroup as api_nodegroup
 from magnum.conductor import api as rpcapi
 import magnum.conf
@@ -40,31 +41,33 @@ class TestNodegroupObject(base.TestCase):
         del nodegroup_dict['max_node_count']
         nodegroup = api_nodegroup.NodeGroup(**nodegroup_dict)
         self.assertEqual(1, nodegroup.node_count)
-        self.assertEqual(1, nodegroup.min_node_count)
+        self.assertEqual(0, nodegroup.min_node_count)
         self.assertIsNone(nodegroup.max_node_count)
 
 
 class NodeGroupControllerTest(api_base.FunctionalTest):
     headers = {"Openstack-Api-Version": "container-infra latest"}
 
-    def _add_headers(self, kwargs):
+    def _add_headers(self, kwargs, roles=None):
         if 'headers' not in kwargs:
             kwargs['headers'] = self.headers
+            if roles:
+                kwargs['headers']['X-Roles'] = ",".join(roles)
 
     def get_json(self, *args, **kwargs):
-        self._add_headers(kwargs)
+        self._add_headers(kwargs, roles=['reader'])
         return super(NodeGroupControllerTest, self).get_json(*args, **kwargs)
 
     def post_json(self, *args, **kwargs):
-        self._add_headers(kwargs)
+        self._add_headers(kwargs, roles=['member'])
         return super(NodeGroupControllerTest, self).post_json(*args, **kwargs)
 
     def delete(self, *args, **kwargs):
-        self._add_headers(kwargs)
+        self._add_headers(kwargs, roles=['member'])
         return super(NodeGroupControllerTest, self).delete(*args, **kwargs)
 
     def patch_json(self, *args, **kwargs):
-        self._add_headers(kwargs)
+        self._add_headers(kwargs, roles=['member'])
         return super(NodeGroupControllerTest, self).patch_json(*args, **kwargs)
 
 
@@ -250,6 +253,24 @@ class TestListNodegroups(NodeGroupControllerTest):
         response = self.get_json(url, headers=headers, expect_errors=True)
         self.assertEqual(406, response.status_code)
 
+    def test_get_all_api_minor_version_above_range(self):
+        headers = {"Openstack-Api-Version": "container-infra 1.999"}
+        url = '/clusters/%s/nodegroups/' % (self.cluster.uuid)
+        response = self.get_json(url, headers=headers, expect_errors=True)
+        self.assertEqual(406, response.status_code)
+        self.assertIsNotNone(response.json['errors'])
+        self.assertEqual('magnum.microversion-unsupported',
+                         response.json['errors'][0]['code'])
+
+    def test_get_all_api_major_version_above_range(self):
+        headers = {"Openstack-Api-Version": "container-infra 2.11"}
+        url = '/clusters/%s/nodegroups/' % (self.cluster.uuid)
+        response = self.get_json(url, headers=headers, expect_errors=True)
+        self.assertEqual(406, response.status_code)
+        self.assertIsNotNone(response.json['errors'])
+        self.assertEqual('magnum.microversion-unsupported',
+                         response.json['errors'][0]['code'])
+
 
 class TestPost(NodeGroupControllerTest):
     def setUp(self):
@@ -263,6 +284,10 @@ class TestPost(NodeGroupControllerTest):
         self.mock_ng_create.side_effect = self._simulate_nodegroup_create
         self.addCleanup(p.stop)
         self.url = "/clusters/%s/nodegroups" % self.cluster.uuid
+        p = mock.patch.object(
+            attr_validator, 'validate_flavor_root_volume_size')
+        self.mock_valid_flavor_disk = p.start()
+        self.addCleanup(p.stop)
 
     def _simulate_nodegroup_create(self, cluster, nodegroup):
         nodegroup.create()
@@ -293,6 +318,20 @@ class TestPost(NodeGroupControllerTest):
         # Verify node_count defaults to 1
         self.assertEqual(1, response.json['node_count'])
 
+    @mock.patch('oslo_utils.timeutils.utcnow')
+    def test_create_nodegroup_with_zero_nodes(self, mock_utcnow):
+        ng_dict = apiutils.nodegroup_post_data()
+        ng_dict['node_count'] = 0
+        ng_dict['min_node_count'] = 0
+        test_time = datetime.datetime(2000, 1, 1, 0, 0)
+        mock_utcnow.return_value = test_time
+
+        response = self.post_json(self.url, ng_dict)
+        self.assertEqual('application/json', response.content_type)
+        self.assertEqual(202, response.status_int)
+        # Verify node_count is set to zero
+        self.assertEqual(0, response.json['node_count'])
+
     @mock.patch('oslo_utils.timeutils.utcnow')
     def test_create_nodegroup_with_max_node_count(self, mock_utcnow):
         ng_dict = apiutils.nodegroup_post_data(max_node_count=5)
@@ -366,7 +405,7 @@ class TestPost(NodeGroupControllerTest):
         self.assertEqual(self.cluster.project_id, response.json['project_id'])
         self.assertEqual(self.cluster.labels, response.json['labels'])
         self.assertEqual('worker', response.json['role'])
-        self.assertEqual(1, response.json['min_node_count'])
+        self.assertEqual(0, response.json['min_node_count'])
         self.assertEqual(1, response.json['node_count'])
         self.assertIsNone(response.json['max_node_count'])
 
@@ -555,6 +594,10 @@ class TestPatch(NodeGroupControllerTest):
         self.mock_ng_update.side_effect = self._simulate_nodegroup_update
         self.addCleanup(p.stop)
         self.url = "/clusters/%s/nodegroups/" % self.cluster.uuid
+        p = mock.patch.object(
+            attr_validator, 'validate_flavor_root_volume_size')
+        self.mock_valid_flavor_disk = p.start()
+        self.addCleanup(p.stop)
 
     def _simulate_nodegroup_update(self, cluster, nodegroup):
         nodegroup.save()
@@ -662,7 +705,7 @@ class TestPatch(NodeGroupControllerTest):
 
         response = self.get_json(self.url + self.nodegroup.uuid)
         # Removing the min_node_count just restores the default value
-        self.assertEqual(1, response['min_node_count'])
+        self.assertEqual(0, response['min_node_count'])
         return_updated_at = timeutils.parse_isotime(
             response['updated_at']).replace(tzinfo=None)
         self.assertEqual(test_time, return_updated_at)
