@@ -16,8 +16,7 @@ from unittest import mock
 from unittest.mock import patch
 
 import magnum.conf
-from magnum.drivers.k8s_coreos_v1 import driver as k8s_coreos_dr
-from magnum.drivers.k8s_fedora_atomic_v1 import driver as k8s_dr
+from magnum.drivers.k8s_fedora_coreos_v1 import driver as k8s_fcos_dr
 from magnum import objects
 from magnum.tests import base
 
@@ -49,7 +48,7 @@ class TestClusterConductorWithK8s(base.TestCase):
             'volume_driver': 'volume_driver',
             'docker_volume_size': 20,
             'docker_storage_driver': 'devicemapper',
-            'cluster_distro': 'fedora-atomic',
+            'cluster_distro': 'fedora-coreos',
             'coe': 'kubernetes',
             'token': None,
             'http_proxy': 'http_proxy',
@@ -245,7 +244,7 @@ class TestClusterConductorWithK8s(base.TestCase):
         worker_ng = objects.NodeGroup(self.context, **self.worker_ng_dict)
         master_ng = objects.NodeGroup(self.context, **self.master_ng_dict)
         mock_objects_nodegroup_list.return_value = [master_ng, worker_ng]
-        mock_driver.return_value = k8s_dr.Driver()
+        mock_driver.return_value = k8s_fcos_dr.Driver()
 
         mock_get_subnet.return_value = self.fixed_subnet_cidr
 
@@ -440,7 +439,7 @@ class TestClusterConductorWithK8s(base.TestCase):
         worker_ng = objects.NodeGroup(self.context, **self.worker_ng_dict)
         master_ng = objects.NodeGroup(self.context, **self.master_ng_dict)
         mock_objects_nodegroup_list.return_value = [master_ng, worker_ng]
-        mock_driver.return_value = k8s_dr.Driver()
+        mock_driver.return_value = k8s_fcos_dr.Driver()
         mock_get_subnet.return_value = self.fixed_subnet_cidr
 
         CONF.set_override('swift_region',
@@ -593,7 +592,7 @@ class TestClusterConductorWithK8s(base.TestCase):
         mock_resp = mock.MagicMock()
         mock_resp.text = expected_result
         mock_get.return_value = mock_resp
-        mock_driver.return_value = k8s_dr.Driver()
+        mock_driver.return_value = k8s_fcos_dr.Driver()
         cluster = objects.Cluster(self.context, **self.cluster_dict)
         del self.worker_ng_dict['image_id']
         worker_ng = objects.NodeGroup(self.context, **self.worker_ng_dict)
@@ -698,16 +697,21 @@ class TestClusterConductorWithK8s(base.TestCase):
     @patch('magnum.objects.ClusterTemplate.get_by_uuid')
     @patch('magnum.objects.NodeGroup.list')
     @patch('magnum.drivers.common.driver.Driver.get_driver')
-    def test_extract_template_definition_coreos_with_disovery(
+    @patch('magnum.common.x509.operations.generate_csr_and_key')
+    def test_extract_template_definition_fcos_with_discovery(
             self,
+            mock_generate_csr_and_key,
             mock_driver,
             mock_objects_nodegroup_list,
             mock_objects_cluster_template_get_by_uuid,
             mock_get,
             mock_get_subnet):
-        self.cluster_template_dict['cluster_distro'] = 'coreos'
+        self.cluster_template_dict['cluster_distro'] = 'fedora-coreos'
         cluster_template = objects.ClusterTemplate(
             self.context, **self.cluster_template_dict)
+        mock_generate_csr_and_key.return_value = {'csr': 'csr',
+                                                  'private_key': 'private_key',
+                                                  'public_key': 'public_key'}
         mock_objects_cluster_template_get_by_uuid.return_value = \
             cluster_template
         expected_result = str('{"action":"get","node":{"key":"test","value":'
@@ -720,7 +724,7 @@ class TestClusterConductorWithK8s(base.TestCase):
         worker_ng = objects.NodeGroup(self.context, **self.worker_ng_dict)
         master_ng = objects.NodeGroup(self.context, **self.master_ng_dict)
         mock_objects_nodegroup_list.return_value = [master_ng, worker_ng]
-        mock_driver.return_value = k8s_coreos_dr.Driver()
+        mock_driver.return_value = k8s_fcos_dr.Driver()
         mock_get_subnet.return_value = self.fixed_subnet_cidr
 
         (template_path,
@@ -729,6 +733,16 @@ class TestClusterConductorWithK8s(base.TestCase):
                                                                  cluster)
 
         expected = {
+            'boot_volume_size': '60',
+            'boot_volume_type': 'lvmdriver-1',
+            'etcd_volume_type': '',
+            'max_node_count': 2,
+            'post_install_manifest_url': '',
+            'project_id': 'project_id',
+            'keystone_auth_default_policy': self.keystone_auth_default_policy,
+            'kube_service_account_key': 'public_key',
+            'kube_service_account_private_key': 'private_key',
+            'cloud_provider_enabled': 'false',
             'ssh_key_name': 'keypair_id',
             'external_network': 'e2a6c8b0-a3c2-42a3-b3f4-01400a30896e',
             'fixed_network': 'fixed_network',
@@ -780,7 +794,6 @@ class TestClusterConductorWithK8s(base.TestCase):
             'verify_ca': True,
             'openstack_ca': '',
             'ssh_public_key': 'ssh-rsa AAAAB3Nz',
-            'openstack_ca_coreos': '',
             'cert_manager_api': 'False',
             'ingress_controller': 'i-controller',
             'ingress_controller_role': 'i-controller-role',
@@ -818,27 +831,32 @@ class TestClusterConductorWithK8s(base.TestCase):
     @patch('magnum.objects.ClusterTemplate.get_by_uuid')
     @patch('magnum.objects.NodeGroup.list')
     @patch('magnum.drivers.common.driver.Driver.get_driver')
-    def test_extract_template_definition_coreos_no_discoveryurl(
+    @patch('magnum.common.x509.operations.generate_csr_and_key')
+    def test_extract_template_definition_fcos_no_discoveryurl(
             self,
+            mock_generate_csr_and_key,
             mock_driver,
             mock_objects_nodegroup_list,
             mock_objects_cluster_template_get_by_uuid,
             reqget,
             mock_get_subnet):
-        self.cluster_template_dict['cluster_distro'] = 'coreos'
+        self.cluster_template_dict['cluster_distro'] = 'fedora-coreos'
         self.cluster_dict['discovery_url'] = None
         mock_req = mock.MagicMock(text='http://tokentest/h1/h2/h3',
                                   status_code=200)
         reqget.return_value = mock_req
         cluster_template = objects.ClusterTemplate(
             self.context, **self.cluster_template_dict)
+        mock_generate_csr_and_key.return_value = {'csr': 'csr',
+                                                  'private_key': 'private_key',
+                                                  'public_key': 'public_key'}
         mock_objects_cluster_template_get_by_uuid.return_value = \
             cluster_template
         cluster = objects.Cluster(self.context, **self.cluster_dict)
         worker_ng = objects.NodeGroup(self.context, **self.worker_ng_dict)
         master_ng = objects.NodeGroup(self.context, **self.master_ng_dict)
         mock_objects_nodegroup_list.return_value = [master_ng, worker_ng]
-        mock_driver.return_value = k8s_coreos_dr.Driver()
+        mock_driver.return_value = k8s_fcos_dr.Driver()
         mock_get_subnet.return_value = self.fixed_subnet_cidr
 
         (template_path,
@@ -847,6 +865,16 @@ class TestClusterConductorWithK8s(base.TestCase):
                                                                  cluster)
 
         expected = {
+            'boot_volume_size': '60',
+            'boot_volume_type': 'lvmdriver-1',
+            'etcd_volume_type': '',
+            'max_node_count': 2,
+            'post_install_manifest_url': '',
+            'project_id': 'project_id',
+            'keystone_auth_default_policy': self.keystone_auth_default_policy,
+            'kube_service_account_key': 'public_key',
+            'kube_service_account_private_key': 'private_key',
+            'cloud_provider_enabled': 'false',
             'ssh_key_name': 'keypair_id',
             'availability_zone': 'az_1',
             'external_network': 'e2a6c8b0-a3c2-42a3-b3f4-01400a30896e',
@@ -898,7 +926,6 @@ class TestClusterConductorWithK8s(base.TestCase):
             'verify_ca': True,
             'openstack_ca': '',
             'ssh_public_key': 'ssh-rsa AAAAB3Nz',
-            'openstack_ca_coreos': '',
             'cert_manager_api': 'False',
             'ingress_controller': 'i-controller',
             'ingress_controller_role': 'i-controller-role',
@@ -948,7 +975,7 @@ class TestClusterConductorWithK8s(base.TestCase):
             mock_objects_cluster_template_get_by_uuid,
             mock_get,
             mock_get_subnet):
-        mock_driver.return_value = k8s_dr.Driver()
+        mock_driver.return_value = k8s_fcos_dr.Driver()
         self._test_extract_template_definition(
             mock_generate_csr_and_key,
             mock_sign_node_certificate,
@@ -976,7 +1003,7 @@ class TestClusterConductorWithK8s(base.TestCase):
             mock_objects_cluster_template_get_by_uuid,
             mock_get,
             mock_get_subnet):
-        mock_driver.return_value = k8s_dr.Driver()
+        mock_driver.return_value = k8s_fcos_dr.Driver()
         self._test_extract_template_definition(
             mock_generate_csr_and_key,
             mock_sign_node_certificate,
@@ -1004,7 +1031,7 @@ class TestClusterConductorWithK8s(base.TestCase):
             mock_objects_cluster_template_get_by_uuid,
             mock_get,
             mock_get_subnet):
-        mock_driver.return_value = k8s_dr.Driver()
+        mock_driver.return_value = k8s_fcos_dr.Driver()
         self._test_extract_template_definition(
             mock_generate_csr_and_key,
             mock_sign_node_certificate,
@@ -1032,7 +1059,7 @@ class TestClusterConductorWithK8s(base.TestCase):
             mock_objects_cluster_template_get_by_uuid,
             mock_get,
             mock_get_subnet):
-        mock_driver.return_value = k8s_dr.Driver()
+        mock_driver.return_value = k8s_fcos_dr.Driver()
         self._test_extract_template_definition(
             mock_generate_csr_and_key,
             mock_sign_node_certificate,
@@ -1074,7 +1101,7 @@ class TestClusterConductorWithK8s(base.TestCase):
         worker_ng = objects.NodeGroup(self.context, **self.worker_ng_dict)
         master_ng = objects.NodeGroup(self.context, **self.master_ng_dict)
         mock_objects_nodegroup_list.return_value = [master_ng, worker_ng]
-        mock_driver.return_value = k8s_dr.Driver()
+        mock_driver.return_value = k8s_fcos_dr.Driver()
 
         CONF.set_override('etcd_discovery_service_endpoint_format',
                           'http://etcd/test?size=%(size)d',
@@ -1186,7 +1213,7 @@ class TestClusterConductorWithK8s(base.TestCase):
 
     @patch('magnum.common.short_id.generate_id')
     @patch('heatclient.common.template_utils.get_template_contents')
-    @patch('magnum.drivers.k8s_fedora_atomic_v1.driver.Driver.'
+    @patch('magnum.drivers.k8s_fedora_coreos_v1.driver.Driver.'
            '_extract_template_definition')
     @patch('magnum.common.clients.OpenStackClients')
     def test_create_stack(self,
@@ -1211,8 +1238,8 @@ class TestClusterConductorWithK8s(base.TestCase):
         mock_cluster = mock.MagicMock()
         mock_cluster.name = dummy_cluster_name
 
-        k8s_dr.Driver().create_cluster(self.context, mock_cluster,
-                                       expected_timeout)
+        k8s_fcos_dr.Driver().create_cluster(self.context, mock_cluster,
+                                            expected_timeout)
 
         expected_args = {
             'stack_name': expected_stack_name,
@@ -1226,7 +1253,7 @@ class TestClusterConductorWithK8s(base.TestCase):
 
     @patch('magnum.common.short_id.generate_id')
     @patch('heatclient.common.template_utils.get_template_contents')
-    @patch('magnum.drivers.k8s_fedora_atomic_v1.driver.Driver.'
+    @patch('magnum.drivers.k8s_fedora_coreos_v1.driver.Driver.'
            '_extract_template_definition')
     @patch('magnum.common.clients.OpenStackClients')
     def test_create_stack_no_timeout_specified(
@@ -1252,7 +1279,7 @@ class TestClusterConductorWithK8s(base.TestCase):
         mock_cluster = mock.MagicMock()
         mock_cluster.name = dummy_cluster_name
 
-        k8s_dr.Driver().create_cluster(self.context, mock_cluster, None)
+        k8s_fcos_dr.Driver().create_cluster(self.context, mock_cluster, None)
 
         expected_args = {
             'stack_name': expected_stack_name,
@@ -1266,7 +1293,7 @@ class TestClusterConductorWithK8s(base.TestCase):
 
     @patch('magnum.common.short_id.generate_id')
     @patch('heatclient.common.template_utils.get_template_contents')
-    @patch('magnum.drivers.k8s_fedora_atomic_v1.driver.Driver.'
+    @patch('magnum.drivers.k8s_fedora_coreos_v1.driver.Driver.'
            '_extract_template_definition')
     @patch('magnum.common.clients.OpenStackClients')
     def test_create_stack_timeout_is_zero(
@@ -1293,8 +1320,8 @@ class TestClusterConductorWithK8s(base.TestCase):
         mock_cluster = mock.MagicMock()
         mock_cluster.name = dummy_cluster_name
 
-        k8s_dr.Driver().create_cluster(self.context, mock_cluster,
-                                       cluster_timeout)
+        k8s_fcos_dr.Driver().create_cluster(self.context, mock_cluster,
+                                            cluster_timeout)
 
         expected_args = {
             'stack_name': expected_stack_name,
@@ -1307,7 +1334,7 @@ class TestClusterConductorWithK8s(base.TestCase):
         mock_heat_client.stacks.create.assert_called_once_with(**expected_args)
 
     @patch('heatclient.common.template_utils.get_template_contents')
-    @patch('magnum.drivers.k8s_fedora_atomic_v1.driver.Driver.'
+    @patch('magnum.drivers.k8s_fedora_coreos_v1.driver.Driver.'
            '_extract_template_definition')
     @patch('magnum.common.clients.OpenStackClients')
     @patch('magnum.objects.ClusterTemplate.get_by_uuid')
@@ -1336,7 +1363,7 @@ class TestClusterConductorWithK8s(base.TestCase):
         master_ng = objects.NodeGroup(self.context, **self.master_ng_dict)
         mock_objects_nodegroup_list.return_value = [master_ng, worker_ng]
 
-        k8s_dr.Driver().update_cluster({}, mock_cluster)
+        k8s_fcos_dr.Driver().update_cluster({}, mock_cluster)
 
         expected_args = {
             'parameters': {'number_of_minions': 2},
