@@ -17,10 +17,8 @@
 
 import datetime
 
-import iso8601
 import netaddr
 from oslo_utils import timeutils
-import six
 
 from magnum.common import exception
 from magnum.i18n import _
@@ -84,8 +82,10 @@ def create_test_cluster(context, **kw):
     """
     cluster = get_test_cluster(context, **kw)
     create_test_cluster_template(context, uuid=cluster['cluster_template_id'],
-                                 coe=kw.get('coe', 'swarm'),
+                                 coe=kw.get('coe', 'kubernetes'),
                                  tls_disabled=kw.get('tls_disabled'))
+    kw.update({'cluster_id': cluster['uuid']})
+    db_utils.create_nodegroups_for_cluster(**kw)
     cluster.create()
     return cluster
 
@@ -157,6 +157,47 @@ def get_test_magnum_service_object(context, **kw):
     return magnum_service
 
 
+def get_test_nodegroup(context, **kw):
+    db_nodegroup = db_utils.get_test_nodegroup(**kw)
+    nodegroup = objects.NodeGroup(context)
+    for key in db_nodegroup:
+        setattr(nodegroup, key, db_nodegroup[key])
+    return nodegroup
+
+
+def create_test_nodegroup(context, **kw):
+    nodegroup = get_test_nodegroup(context, **kw)
+    nodegroup.create()
+    return nodegroup
+
+
+def get_test_federation(context, **kw):
+    """Return a Federation object with appropriate attributes.
+
+    NOTE: The object leaves the attributes marked as changed, such
+    that a create() could be used to commit it to the DB.
+    """
+    db_federation = db_utils.get_test_federation(**kw)
+    # Let DB generate ID if it isn't specified explicitly
+    if 'id' not in kw:
+        del db_federation['id']
+    federation = objects.Federation(context)
+    for key in db_federation:
+        setattr(federation, key, db_federation[key])
+    return federation
+
+
+def create_test_federation(context, **kw):
+    """Create and return a test Federation object.
+
+    Create a Federation in the DB and return a Federation object with
+    appropriate attributes.
+    """
+    federation = get_test_federation(context, **kw)
+    federation.create()
+    return federation
+
+
 def datetime_or_none(dt):
     """Validate a datetime or None value."""
     if dt is None:
@@ -166,14 +207,14 @@ def datetime_or_none(dt):
             # NOTE(danms): Legacy objects from sqlalchemy are stored in UTC,
             # but are returned without a timezone attached.
             # As a transitional aid, assume a tz-naive object is in UTC.
-            return dt.replace(tzinfo=iso8601.UTC)
+            return dt.replace(tzinfo=datetime.timezone.utc)
         else:
             return dt
     raise ValueError(_("A datetime.datetime is required here"))
 
 
 def datetime_or_str_or_none(val):
-    if isinstance(val, six.string_types):
+    if isinstance(val, str):
         return timeutils.parse_isotime(val)
     return datetime_or_none(val)
 
@@ -191,7 +232,7 @@ def str_or_none(val):
     if val is None:
         return val
     else:
-        return six.text_type(val)
+        return str(val)
 
 
 def ip_or_none(version):
